Index

- Push section

  This controller simply pushes a new section on top of the navigation stack.

- JS call Native

  This is the simplest way to open the application's sidebar from JavaScript.

- Native call JS

  Get your device's name from he This event chain will trigger a native method that after is done processing will pass the result to the JavaScript part and it will be displayed inside a dialog.

- Push native Section

  Create a new native section and push it on top of the navigation stack.

- Padding item

  This item has no action bound to it and is here just for padding to enable scrolling on all devices.

- Padding item

  This item has no action bound to it and is here just for padding to enable scrolling on all devices.

- Padding item

  This item has no action bound to it and is here just for padding to enable scrolling on all devices.

- Padding item

  This item has no action bound to it and is here just for padding to enable scrolling on all devices.

- Scroll back up

  Trigger a JavaScript event that will scroll the top of the page.